ProSHADE: Member List

| ProSHADE 0.7.5.1 (JAN 2021) Protein Shape Detection

ProSHADE_internal_maths::BicubicInterpolator Member List

This is the complete list of members for ProSHADE_internal_maths::BicubicInterpolator, including all inherited members.

BicubicInterpolator(proshade_double **areaToInterpolate, proshade_double xStart, proshade_double yStart) | ProSHADE_internal_maths::BicubicInterpolator | inline
getValue(proshade_double x, proshade_double y) | ProSHADE_internal_maths::BicubicInterpolator | inline
~BicubicInterpolator(void) | ProSHADE_internal_maths::BicubicInterpolator | inline